==> cloudfoundry-client-3.5.0.BUILD-20180201.140059-3-sources.jar: org/cloudfoundry/client/v2/userprovidedserviceinstances/_UpdateUserProvidedServiceInstanceRequest.java <==
/*
 * Copyright 2013-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v2.userprovidedserviceinstances;


import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.cloudfoundry.AllowNulls;
import org.cloudfoundry.Nullable;
import org.immutables.value.Value;

import java.util.Map;

/**
 * The request payload for the Update User Provided Service Instance
 */
@Value.Immutable
abstract class _UpdateUserProvidedServiceInstanceRequest {

    /**
     * Key/value pairs that can be stored to store credentials
     */
    @AllowNulls
    @JsonProperty("credentials")
    @Nullable
    abstract Map<String, Object> getCredentials();

    /**
     * The name
     */
    @JsonProperty("name")
    @Nullable
    abstract String getName();

    /**
     * URL to which requests for bound routes will be forwarded
     */
    @JsonProperty("route_service_url")
    @Nullable
    abstract String getRouteServiceUrl();

    /**
     * The url for the syslog_drain to direct to
     */
    @JsonProperty("syslog_drain_url")
    @Nullable
    abstract String getSyslogDrainUrl();

    /**
     * The user provided service instance id
     */
    @JsonIgnore
    abstract String getUserProvidedServiceInstanceId();

}

==> cloudfoundry-client-4.14.0.BUILD-20210114.230026-3-sources.jar: org/cloudfoundry/client/v2/userprovidedserviceinstances/_UpdateUserProvidedServiceInstanceRequest.java <==
/*
 * Copyright 2013-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v2.userprovidedserviceinstances;


import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import org.cloudfoundry.AllowNulls;
import org.cloudfoundry.Nullable;
import org.immutables.value.Value;

import java.util.List;
import java.util.Map;

/**
 * The request payload for the Update User Provided Service Instance
 */
@JsonSerialize
@Value.Immutable
abstract class _UpdateUserProvidedServiceInstanceRequest {

    /**
     * Key/value pairs that can be stored to store credentials
     */
    @AllowNulls
    @JsonProperty("credentials")
    @Nullable
    abstract Map<String, Object> getCredentials();

    /**
     * The name
     */
    @JsonProperty("name")
    @Nullable
    abstract String getName();

    /**
     * URL to which requests for bound routes will be forwarded
     */
    @JsonProperty("route_service_url")
    @Nullable
    abstract String getRouteServiceUrl();

    /**
     * The url for the syslog_drain to direct to
     */
    @JsonProperty("syslog_drain_url")
    @Nullable
    abstract String getSyslogDrainUrl();

    /**
     * The tags
     */
    @JsonProperty
    @Nullable
    abstract List<String> getTags();

    /**
     * The user provided service instance id
     */
    @JsonIgnore
    abstract String getUserProvidedServiceInstanceId();

}
